## Summary

<!-- What does this PR do and why? -->

## Changes

<!-- Bullet list of key changes -->

## Test Plan

- [ ] Unit tests added/updated
- [ ] Integration tests added/updated (if applicable)
- [ ] All existing tests pass (`pytest`)
- [ ] Linting passes (`ruff check gleanr/`)
- [ ] Type checking passes (`mypy gleanr/`)
